.. _promotion:

Promotion
---------


One benefit of creating a PyLadies chapter is having access to a
worldwide support network of PyLadies who can help you spread word about
your events.

How to promote your events locally
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Do the following:

#. Post an event description on your `meetup.com <http://meetup.com>`_
   page or website.
#. Announce the event via your mailing list.
#. Create event flyers and distribute them at meetups, Python user group
   meetings, work, and the local universities. See [upload example or
   template to git repo] for an example.
#. Approach the career offices and engineering/science departments of
   local colleges and universities.
#. Contact old professors and teachers. Tell them about what you’re
   doing; they’ll be glad to hear from you. Ask to make an announcement
   to their current students at the start of their classes, or as an
   email.
#. Attend local tech/Python meetups. Be an active part of the local
   developer community. Show that you care about getting more women into
   Python development and programming in general. Be humble and ask for
   help from the group.

How we can help
~~~~~~~~~~~~~~~

Email the main point of contact for any of the following channels, and
provide text and/or images for us to use:

#. Global PyLadies Newsletter: Good for announcements about meetups.
   Subscribers from all over the world. Please keep the text
   brief and include an image. (info@pyladies.com)
#. PyLadies blog: we would love for you to contribute posts to our blog!
   It's as simple as forking and then making a pull request off
   http://github.com/pyladies/pyladies

In addition, promote all of your events directly through the following:
6. PyLadies Google group: http://groups.google.com/group/pyladies
7. #pyladies IRC channel (FreeNode)

Whenever you have news of interest to the PyLadies community, all the
above channels are available to help you make your announcement. We are
always looking for good quotes and photos from Python developer women.


Guidelines for using the PyLadies promotion channels
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Anything of interest to women in the Python community can be posted in
the various PyLadies channels, provided that it meets these guidelines:

#. **Send us the actual text that you want posted.**
#. For local PyLadies chapter events:

   * Send text for as many events as possible to the channels listed above.
     The more we can promote your events, the better.
#. For non-chapter events and general postings:

   * Postings should be relevant to women.  Mention the women organizing
     and/or attending the event.  Have their names link to their websites or
     Twitter accounts.
   * Don't just reuse the same blurb that you use everywhere; customize it to
     be relevant to the specific audience you're addressing.
   * We'd love to use the various channels to feature what PyLadies from
     everywhere are doing.  If you know of someone who should be featured,
     you can write up something interesting for the blog, Twitter stream, etc.
   * If you are hosting a Python community event or conference and need our
     help getting more women to attend, submit proposals, etc., a heartfelt
     explanation about why more women should attend and feel welcome goes a
     long way. A PyLadies discount code also helps: keep in mind that a huge
     part of our audience are students/those just starting out professionally
     with Python, who cannot afford to commit to events or submit
     proposals unless there is a known, guaranteed PyLadies discount.